
/*
 * DSPAMINFO.C	Dump the spam cache (for debugging)
 *
 * (c)Copyright 1997, Matthew Dillon, All Rights Reserved.  Refer to
 *    the COPYRIGHT file in the base directory of this distribution 
 *    for specific rights granted.
 */

#include "defs.h"

int
main(int ac, char **av)
{
    LoadDiabloConfig(ac, av);
    DumpSpamFilterCache(stdout);
    return(0);
}

